@@ -4,8 +4,8 @@
 
 ;; Author: Grant Surlyn <grant@sunflowerseastar.com>
 ;; URL: https://github.com/sunflowerseastar/ob-llm
-;; Package-Version: 20250630.303
-;; Package-Revision: f667dbce7fb3
+;; Package-Version: 20251208.18
+;; Package-Revision: 16237613f3ce
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: llm org-mode tools convenience org babel
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -322,7 +322,7 @@ that point."
   (with-temp-buffer
     (insert text)
     (let* ((pandoc-args
-            (append '("--from" "markdown+hard_line_breaks-simple_tables" "--to" "org"
+            (append '("--from" "gfm+hard_line_breaks" "--to" "org"
                       "--sandbox=true" "--wrap=none")
                     ob-llm-pandoc-additional-org-mode-conversion-flags))
            (pandoc-status
